FFmpeg
Loading...
Searching...
No Matches
timestamp.c
Go to the documentation of this file.
1/*
2 * This file is part of FFmpeg.
3 *
4 * FFmpeg is free software; you can redistribute it and/or
5 * modify it under the terms of the GNU Lesser General Public
6 * License as published by the Free Software Foundation; either
7 * version 2.1 of the License, or (at your option) any later version.
8 *
9 * FFmpeg is distributed in the hope that it will be useful,
10 * but WITHOUT ANY WARRANTY; without even the implied warranty of
11 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
12 * Lesser General Public License for more details.
13 *
14 * You should have received a copy of the GNU Lesser General Public
15 * License along with FFmpeg; if not, write to the Free Software
16 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
17 */
18
19#include "timestamp.h"
20
22{
23 if (ts == AV_NOPTS_VALUE) {
24 snprintf(buf, AV_TS_MAX_STRING_SIZE, "NOPTS");
25 } else {
26 double val = av_q2d(tb) * ts;
27 double log = (fpclassify(val) == FP_ZERO ? -INFINITY : floor(log10(fabs(val))));
28 int precision = (isfinite(log) && log < 0) ? -log + 5 : 6;
29 int last = snprintf(buf, AV_TS_MAX_STRING_SIZE, "%.*f", precision, val);
30 last = FFMIN(last, AV_TS_MAX_STRING_SIZE - 1) - 1;
31 for (; last && buf[last] == '0'; last--);
32 for (; last && buf[last] != 'f' && (buf[last] < '0' || buf[0] > '9'); last--);
33 buf[last + 1] = '\0';
34 }
35 return buf;
36}
static double val(void *priv, double ch)
Definition aeval.c:77
long long int64_t
Definition coverity.c:34
static __device__ float fabs(float a)
static __device__ float floor(float a)
static double av_q2d(AVRational a)
Convert an AVRational to a double.
Definition rational.h:104
#define AV_NOPTS_VALUE
Undefined timestamp value.
Definition avutil.h:247
#define isfinite(x)
Definition libm.h:361
#define FFMIN(a, b)
Definition macros.h:49
#define INFINITY
#define snprintf
Definition snprintf.h:34
Rational number (pair of numerator and denominator).
Definition rational.h:58
char * av_ts_make_time_string2(char *buf, int64_t ts, AVRational tb)
Fill the provided buffer with a string containing a timestamp time representation.
Definition timestamp.c:21
timestamp utils, mostly useful for debugging/logging purposes
#define AV_TS_MAX_STRING_SIZE
Definition timestamp.h:33